==> aws-java-sdk-simpleworkflow-1.10.77-sources.jar: com/amazonaws/services/simpleworkflow/model/transform/ActivityTaskFailedEventAttributesJsonMarshaller.java <==
/*
 * Copyright 2010-2016 Amazon.com, Inc. or its affiliates. All Rights
 * Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License").
 * You may not use this file except in compliance with the License.
 * A copy of the License is located at
 *
 *  http://aws.amazon.com/apache2.0
 *
 * or in the "license" file accompanying this file. This file is distributed
 * on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */

package com.amazonaws.services.simpleworkflow.model.transform;

import java.util.Map;
import java.util.List;

import com.amazonaws.AmazonClientException;
import com.amazonaws.services.simpleworkflow.model.*;
import com.amazonaws.transform.Marshaller;
import com.amazonaws.util.BinaryUtils;
import com.amazonaws.util.StringUtils;
import com.amazonaws.util.IdempotentUtils;
import com.amazonaws.util.StringInputStream;
import com.amazonaws.util.json.*;

/**
 * ActivityTaskFailedEventAttributesMarshaller
 */
public class ActivityTaskFailedEventAttributesJsonMarshaller {

    /**
     * Marshall the given parameter object, and output to a SdkJsonGenerator
     */
    public void marshall(
            ActivityTaskFailedEventAttributes activityTaskFailedEventAttributes,
            StructuredJsonGenerator jsonGenerator) {

        if (activityTaskFailedEventAttributes == null) {
            throw new AmazonClientException(
                    "Invalid argument passed to marshall(...)");
        }

        try {
            jsonGenerator.writeStartObject();

            if (activityTaskFailedEventAttributes.getReason() != null) {
                jsonGenerator.writeFieldName("reason").writeValue(
                        activityTaskFailedEventAttributes.getReason());
            }
            if (activityTaskFailedEventAttributes.getDetails() != null) {
                jsonGenerator.writeFieldName("details").writeValue(
                        activityTaskFailedEventAttributes.getDetails());
            }
            if (activityTaskFailedEventAttributes.getScheduledEventId() != null) {
                jsonGenerator.writeFieldName("scheduledEventId")
                        .writeValue(
                                activityTaskFailedEventAttributes
                                        .getScheduledEventId());
            }
            if (activityTaskFailedEventAttributes.getStartedEventId() != null) {
                jsonGenerator.writeFieldName("startedEventId").writeValue(
                        activityTaskFailedEventAttributes.getStartedEventId());
            }

            jsonGenerator.writeEndObject();
        } catch (Throwable t) {
            throw new AmazonClientException(
                    "Unable to marshall request to JSON: " + t.getMessage(), t);
        }
    }

    private static ActivityTaskFailedEventAttributesJsonMarshaller instance;

    public static ActivityTaskFailedEventAttributesJsonMarshaller getInstance() {
        if (instance == null)
            instance = new ActivityTaskFailedEventAttributesJsonMarshaller();
        return instance;
    }

}

==> aws-java-sdk-simpleworkflow-1.11.22-sources.jar: com/amazonaws/services/simpleworkflow/model/transform/ActivityTaskFailedEventAttributesJsonMarshaller.java <==
/*
 * Copyright 2011-2016 Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License"). You may not
 * use this file except in compliance with the License. A copy of the License is
 * located at
 * 
 * http://aws.amazon.com/apache2.0
 * 
 * or in the "license" file accompanying this file. This file is distributed on
 * an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */
package com.amazonaws.services.simpleworkflow.model.transform;

import java.util.Map;
import java.util.List;

import com.amazonaws.AmazonClientException;
import com.amazonaws.services.simpleworkflow.model.*;
import com.amazonaws.transform.Marshaller;
import com.amazonaws.util.BinaryUtils;
import com.amazonaws.util.StringUtils;
import com.amazonaws.util.IdempotentUtils;
import com.amazonaws.util.StringInputStream;
import com.amazonaws.protocol.json.*;

/**
 * ActivityTaskFailedEventAttributesMarshaller
 */
public class ActivityTaskFailedEventAttributesJsonMarshaller {

    /**
     * Marshall the given parameter object, and output to a SdkJsonGenerator
     */
    public void marshall(
            ActivityTaskFailedEventAttributes activityTaskFailedEventAttributes,
            StructuredJsonGenerator jsonGenerator) {

        if (activityTaskFailedEventAttributes == null) {
            throw new AmazonClientException(
                    "Invalid argument passed to marshall(...)");
        }

        try {
            jsonGenerator.writeStartObject();

            if (activityTaskFailedEventAttributes.getReason() != null) {
                jsonGenerator.writeFieldName("reason").writeValue(
                        activityTaskFailedEventAttributes.getReason());
            }
            if (activityTaskFailedEventAttributes.getDetails() != null) {
                jsonGenerator.writeFieldName("details").writeValue(
                        activityTaskFailedEventAttributes.getDetails());
            }
            if (activityTaskFailedEventAttributes.getScheduledEventId() != null) {
                jsonGenerator.writeFieldName("scheduledEventId")
                        .writeValue(
                                activityTaskFailedEventAttributes
                                        .getScheduledEventId());
            }
            if (activityTaskFailedEventAttributes.getStartedEventId() != null) {
                jsonGenerator.writeFieldName("startedEventId").writeValue(
                        activityTaskFailedEventAttributes.getStartedEventId());
            }

            jsonGenerator.writeEndObject();
        } catch (Throwable t) {
            throw new AmazonClientException(
                    "Unable to marshall request to JSON: " + t.getMessage(), t);
        }
    }

    private static ActivityTaskFailedEventAttributesJsonMarshaller instance;

    public static ActivityTaskFailedEventAttributesJsonMarshaller getInstance() {
        if (instance == null)
            instance = new ActivityTaskFailedEventAttributesJsonMarshaller();
        return instance;
    }

}
